@@ -1,24 +1,18 @@
 package Example::View::HTML::Contact;
 
-use Moose;
+use Moo;
 use Example::Syntax;
-use Valiant::HTML::TagBuilder 'div', 'fieldset', 'a', 'br', 'button', 'legend', ':utils';
-
-extends 'Example::View::HTML';
+use Example::View::HTML
+  -tags => qw(div a fieldset legend br button form_for),
+  -views => 'HTML::Layout', 'HTML::Navbar';
 
 has 'contact' => (is=>'ro', required=>1);
 
-__PACKAGE__->views(
-  layout => 'HTML::Layout',
-  navbar => 'HTML::Navbar',
-  form_for => 'HTML::FormFor',
-);
-
 sub render($self, $c) {
-  $self->layout(page_title=>'Contact List', sub($layout) {
-    $self->navbar(active_link=>'/contacts'),
-    $self->form_for($self->contact, +{style=>'width:35em; margin:auto'}, sub ($ff, $fb, $contact) {
-      div +{ cond=>$fb->successfully_updated, class=>'alert alert-success', role=>'alert' }, 'Successfully Saved!',
+  html_layout page_title=>'Contact List', sub($layout) {
+    html_navbar active_link=>'/contacts',
+    form_for $self->contact, +{style=>'width:35em; margin:auto'}, sub ($self, $fb, $contact) {
+      div +{ if=>$fb->successfully_updated, class=>'alert alert-success', role=>'alert' }, 'Successfully Saved!',
 
       fieldset [
         $fb->legend,
@@ -44,7 +38,7 @@ sub render($self, $c) {
       fieldset [
         div +{ class=>'form-group' }, [
           $fb->errors_for('emails'),
-          $fb->fields_for('emails', sub($fb_e, $e) {
+          $fb->fields_for('emails', sub($self, $fb_e, $e) {
             $fb_e->legend,
             div +{ class=>'form-row' }, [
               div +{ class=>'col form-group' }, [
@@ -54,11 +48,11 @@ sub render($self, $c) {
               ],
               div +{ class=>'col form-group col-2' }, [
                 $fb_e->label('_delete'), br,
-                $fb_e->checkbox('_delete', +{ checked=>$e->is_marked_for_deletion }),
+                $fb_e->checkbox('_delete'),
               ],
             ]
-          }, sub ($fb_final, $new_e) {
-            $fb_final->button( '_add', +{ value=>1 }, 'Add Email Address');
+          }, sub ($self, $fb_final, $new_e) {
+            $fb_final->button( '_add', 'Add Email Address');
           }),
         ],
       ],
@@ -66,7 +60,7 @@ sub render($self, $c) {
       fieldset [
         div +{ class=>'form-group' }, [
           $fb->errors_for('phones'),
-          $fb->fields_for('phones', sub($fb_e, $e) {
+          $fb->fields_for('phones', sub($self, $fb_e, $e) {
             $fb_e->legend,
             div +{ class=>'form-row' }, [
               div +{ class=>'col form-group' }, [
@@ -76,20 +70,25 @@ sub render($self, $c) {
               ],
               div +{ class=>'col form-group col-2' }, [
                 $fb_e->label('_delete'), br,
-                $fb_e->checkbox('_delete', +{ checked=>$e->is_marked_for_deletion }),
+                $fb_e->checkbox('_delete'),
               ],
             ]
-          }, sub ($fb_final, $new_e) {
-            $fb_final->button( '_add', +{ value=>1 }, 'Add Phone Number');
+          }, sub ($self, $fb_final, $new_e) {
+            $fb_final->button( '_add', 'Add Phone Number');
           }),
         ],
       ],
 
       $fb->submit(),
       a {href=>'/contacts', class=>'btn btn-secondary btn-lg btn-block'}, 'Return to Contact List',
-      button { cond=>$contact->in_storage, formaction=>'?x-tunneled-method=delete', formmethod=>'POST', class=>'btn btn-danger btn-lg btn-block'}, 'Delete Contact',
-    }),
-  });
+      button {
+        if=>$contact->in_storage, 
+        formaction=>'?x-tunneled-method=delete',
+        formmethod=>'POST',
+        class=>'btn btn-danger btn-lg btn-block'
+      }, 'Delete Contact',
+    },
+  };
 }
 
-__PACKAGE__->meta->make_immutable();
+1;
