@@ -1,28 +1,25 @@
 package Example::View::HTML::Login;
  
-use Moose;
+use Moo;
 use Example::Syntax;
-use Valiant::HTML::TagBuilder qw(fieldset input legend div a);
+use Example::View::HTML
+  -tags => qw(fieldset form_for input legend div a),
+  -util => qw($sf content_for path ),
+  -views => 'HTML::Layout';
 
-extends 'Example::View::HTML';
-  
 has 'user' => (is=>'ro', required=>1);
 has 'post_login_redirect' => (is=>'rw', predicate=>'has_post_login_redirect');
 
-__PACKAGE__->views(
-  layout => 'HTML::Layout',
-  form_for => 'HTML::FormFor',
-);
 
-sub action_link($self) {
+sub action_link :Renders ($self) {
   return $self->has_post_login_redirect ?
-    $self->ctx->uri('#login', +{post_login_redirect=>$self->post_login_redirect}) :
-    $self->ctx->uri('#login');
+    path('*Login', +{post_login_redirect=>$self->post_login_redirect}) :
+    path('*Login');
 }
 
 sub render($self, $c) {
-  $self->layout(page_title => 'Sign In', sub($layout) {
-    $self->form_for($self->user, +{action=>$self->action_link, class=>'mx-auto', style=>'width:25em'}, sub ($ff, $fb, $u) {
+  html_layout page_title => 'Sign In', sub($layout) {
+    form_for $self->user, +{action=>$self->action_link, class=>'mx-auto', style=>'width:25em'}, sub ($self, $fb, $u) {
       fieldset [
         legend 'Sign In',
         div +{ class=>'form-group' },
@@ -37,11 +34,11 @@ sub render($self, $c) {
         ],
         $fb->submit('Sign In'),
       ],
-      input {cond=>$self->has_post_login_redirect, type=>'hidden', name=>'post_login_redirect', value=>$self->post_login_redirect},
+      input {if=>$self->has_post_login_redirect, type=>'hidden', name=>'post_login_redirect', value=>$self->post_login_redirect},
       div +{ class=>'text-center' },
         a +{ href=>"/register" }, 'Register';    
-    });
-  });
+    };
+  };
 }
  
-__PACKAGE__->meta->make_immutable();
+1;
